@@ -1,8 +1,6 @@
-library(tinytest)
-
 expect_error(esp_get_hypsobath(epsg = 3367))
-expect_error(esp_get_hypsobath(spatialtype =  "f"))
-expect_error(esp_get_hypsobath(resolution =  "10"))
+expect_error(esp_get_hypsobath(spatialtype = "f"))
+expect_error(esp_get_hypsobath(resolution = "10"))
 
 
 if (giscoR::gisco_check_access()) {
@@ -12,11 +10,12 @@ if (giscoR::gisco_check_access()) {
     epsg = 3857
   ))
 
-  l <- esp_get_hypsobath(spatialtype = "line",
-                         resolution = "6.5",
-                         epsg = 3857)
+  l <- esp_get_hypsobath(
+    spatialtype = "line",
+    resolution = "6.5",
+    epsg = 3857
+  )
 
   expect_true(sf::st_crs(l) == sf::st_crs(3857))
   expect_silent(esp_get_hypsobath(spatialtype = "area", resolution = "6.5"))
-
 }
